function SCDconf_setConf(conf,sourcedd)
% SCDconf_setConf(conf,sourcefile)
%   conf: 'SIM', 'CODE' or use custom conf name
%   sourcedd: source data dictionary containing configurations (Default: configurations_container.sldd)
%
% Sets SCD Simulink configuration settings.
% Takes desired configurationSettings object from sourcefile
% Stores it in configurations/configurations.sldd as configurationSettings

switch lower(conf)
  case 'sim'
    confName = 'configurationSettingsSIM';
  case 'code'
    confName = 'configurationSettingsCODEicc';
  otherwise
    confName = conf; % custom input
end

if nargin==2
  fname_src = sourcedd;
else
  fname_src = 'configurations_container.sldd'; % dd file name
end
fname_target = 'configurations.sldd';
assert(~isempty(which(fname_src)),'%s not in path?',fname_src);
dir_target = fileparts(which(fname_src)); % target dir as source dir
fprintf('Retrieving %s from %s, ',confName,fname_src)
fprintf('setting it as configurationSettings in %s ...\n',fname_target);

dd_src      = Simulink.data.dictionary.open(fname_src);
confSection = getSection(dd_src, 'Configurations');
assert(confSection.exist(confName),'%s does not exist in %s',confName,fname_src);
conf  = confSection.getEntry(confName);
configurationSettings      =  conf.getValue;

%% Set it in target file
% Change name to universal name
configurationSettings.Name = 'configurationSettings';

% open target dd, section
if ~exist(fname_target,'file')
  dd_target = Simulink.data.dictionary.create(fullfile(dir_target,fname_target));
else
  dd_target = Simulink.data.dictionary.open(fname_target);
end
confSection = getSection(dd_target,'Configurations');

% create or set new configurationSettings entry
if confSection.exist('configurationSettings')
  activeconf=confSection.getEntry('configurationSettings');
  activeconf.setValue(configurationSettings);
else
  confSection.addEntry('configurationSettings',configurationSettings)
end
dd_target.saveChanges;
dd_target.close;
end

